@@ -189,6 +189,8 @@ cb_app_delete (GtkWidget *window, GdkEventAny *event, gpointer data)
 		gtk_timeout_remove (procdata->cpu_graph->timer_index);
 	if (procdata->mem_graph)
 		gtk_timeout_remove (procdata->mem_graph->timer_index);
+	if (procdata->net_graph)
+		gtk_timeout_remove (procdata->net_graph->timer_index);
 	if (procdata->disk_timeout != -1)
 		gtk_timeout_remove (procdata->disk_timeout);
 
@@ -198,21 +200,6 @@ cb_app_delete (GtkWidget *window, GdkEventAny *event, gpointer data)
 }
 
 
-void
-cb_proc_combo_changed (GtkComboBox *combo, gpointer data)
-{
-	ProcData * const procdata = data;
-	GConfClient *client;
-
-	g_return_if_fail (procdata);
-
-	client = procdata->client;
-
-	procdata->config.whose_process = gtk_combo_box_get_active (combo);
-	gconf_client_set_int (client, "/apps/procman/view_as",
-			      procdata->config.whose_process, NULL);
-}
-
 
 void
 cb_end_process_button_pressed (GtkButton *button, gpointer data)
@@ -265,6 +252,19 @@ cb_swap_color_changed (GtkColorButton *cp, gpointer data)
 	change_gconf_color(procdata->client, "/apps/procman/swap_color", cp);
 }
 
+void
+cb_net_in_color_changed (GtkColorButton *cp, gpointer data)
+{
+	ProcData * const procdata = data;
+	change_gconf_color(procdata->client, "/apps/procman/net_in_color", cp);
+}
+
+void
+cb_net_out_color_changed (GtkColorButton *cp, gpointer data)
+{
+	ProcData * const procdata = data;
+	change_gconf_color(procdata->client, "/apps/procman/net_out_color", cp);
+}
 
 void
 cb_bg_color_changed (GtkColorButton *cp, gpointer data)
@@ -376,12 +376,15 @@ cb_change_current_page (GtkNotebook *nb, gint num, gpointer data)
 	if (num == 1) {
 		load_graph_start (procdata->cpu_graph);
 		load_graph_start (procdata->mem_graph);
+		load_graph_start (procdata->net_graph);
 		load_graph_draw (procdata->cpu_graph);
 		load_graph_draw (procdata->mem_graph);
+		load_graph_draw (procdata->net_graph);
 	}
 	else {
 		load_graph_stop (procdata->cpu_graph);
 		load_graph_stop (procdata->mem_graph);
+		load_graph_stop (procdata->net_graph);
 	}
 }
 
@@ -424,7 +427,7 @@ update_disk(GtkTreeModel *model, GtkTreeIter *iter, const char *mountdir)
 	free_str  = SI_gnome_vfs_format_file_size_for_display (bfree);
 	total_str = SI_gnome_vfs_format_file_size_for_display (btotal);
 
-	gtk_tree_store_set (GTK_TREE_STORE (model), iter,
+	gtk_list_store_set (GTK_LIST_STORE (model), iter,
 			    4, total_str,
 			    5, free_str,
 			    6, used_str,
@@ -506,8 +509,8 @@ add_new_disks (gpointer key, gpointer value, gpointer data)
 	pixbuf = get_icon_for_device(entry->mountdir);
 
 
-	gtk_tree_store_insert (GTK_TREE_STORE (model), &row, NULL, 0);
-	gtk_tree_store_set (GTK_TREE_STORE (model), &row,
+	gtk_list_store_insert (GTK_LIST_STORE (model), &row, 0);
+	gtk_list_store_set (GTK_LIST_STORE (model), &row,
 			    0, pixbuf,
 			    1, entry->devname,
 			    2, entry->mountdir,
@@ -553,7 +556,7 @@ cb_update_disks (gpointer data)
 	while (old_disks) {
 		GtkTreeIter *iter = old_disks->data;
 
-		gtk_tree_store_remove (GTK_TREE_STORE (model), iter);
+		gtk_list_store_remove (GTK_LIST_STORE (model), iter);
 		gtk_tree_iter_free (iter);
 
 		old_disks = g_list_next (old_disks);
@@ -595,3 +598,15 @@ cb_timeout (gpointer data)
 
 	return TRUE;
 }
+
+
+void
+cb_radio_processes(GtkAction *action, GtkRadioAction *current, gpointer data)
+{
+	ProcData * const procdata = data;
+
+	procdata->config.whose_process = gtk_radio_action_get_current_value(current);
+
+	gconf_client_set_int (procdata->client, "/apps/procman/view_as",
+			      procdata->config.whose_process, NULL);
+}
