@@ -86,6 +86,18 @@ static const GtkToggleActionEntry toggle_menu_entries[] =
 	  G_CALLBACK (cb_toggle_threads), FALSE }
 };
 
+
+static const GtkRadioActionEntry radio_menu_entries[] =
+{
+  { "ShowActiveProcesses", NULL, N_("_Active Processes"), NULL,
+    N_("Show active processes"), ACTIVE_PROCESSES },
+  { "ShowAllProcesses", NULL, N_("A_ll Processes"), NULL,
+    N_("Show all processes"), ALL_PROCESSES },
+  { "ShowMyProcesses", NULL, N_("M_y Processes"), NULL,
+    N_("Show user own process"), MY_PROCESSES }
+};
+
+
 static const char ui_info[] =
 "  <menubar name=\"MenuBar\">"
 "    <menu name=\"FileMenu\" action=\"File\">"
@@ -100,6 +112,10 @@ static const char ui_info[] =
 "      <menuitem name=\"EditPreferenciesMenu\" action=\"Preferencies\" />"
 "    </menu>"
 "    <menu name=\"ViewMenu\" action=\"View\">"
+"      <menuitem name=\"ViewActiveProcesses\" action=\"ShowActiveProcesses\" />"
+"      <menuitem name=\"ViewAllProcesses\" action=\"ShowAllProcesses\" />"
+"      <menuitem name=\"ViewMyProcesses\" action=\"ShowMyProcesses\" />"
+"      <separator />"
 "      <menuitem name=\"ViewDependenciesMenu\" action=\"ShowDependencies\" />"
 "      <menuitem name=\"ViewThreadsMenu\" action=\"ShowThreads\" />"
 "      <separator />"
@@ -132,9 +148,7 @@ create_proc_view (ProcData *procdata)
 {
 	GtkWidget *vbox1, *vbox2;
 	GtkWidget *hbox1;
-	GtkWidget *proc_combo;
 	GtkWidget *scrolled;
-	GtkWidget *label;
 	GtkWidget *hbox2;
 	char* string;
 
@@ -149,22 +163,6 @@ create_proc_view (ProcData *procdata)
 	g_free (string);
 	gtk_box_pack_start (GTK_BOX (hbox1), procdata->loadavg, FALSE, FALSE, 0);
 
-	proc_combo = gtk_combo_box_new_text ();
-	gtk_box_pack_end (GTK_BOX (hbox1), proc_combo, FALSE, FALSE, 0);
-
-	gtk_combo_box_insert_text (GTK_COMBO_BOX (proc_combo), ALL_PROCESSES, _("All processes"));
-	gtk_combo_box_insert_text (GTK_COMBO_BOX (proc_combo), MY_PROCESSES, _("My processes"));
-	gtk_combo_box_insert_text (GTK_COMBO_BOX (proc_combo), ACTIVE_PROCESSES, _("Active processes"));
-
-	gtk_combo_box_set_active (GTK_COMBO_BOX (proc_combo), procdata->config.whose_process);
-
-	g_signal_connect (G_OBJECT (proc_combo), "changed",
-			  G_CALLBACK (cb_proc_combo_changed), procdata);
-
-  	label = gtk_label_new_with_mnemonic (_("Sho_w:"));
-  	gtk_label_set_mnemonic_widget (GTK_LABEL (label), proc_combo);
-	gtk_box_pack_end (GTK_BOX (hbox1), label, FALSE, FALSE, 0);
-
 	gtk_widget_show_all (hbox1);
 
 	scrolled = proctable_new (procdata);
@@ -252,6 +250,12 @@ cpu_size_request (GtkWidget *box, GtkRequisition *req, ProcData *procdata)
 		MAX(req->width, procdata->cpu_label_fixed_width);
 }
 
+static void
+net_size_request (GtkWidget *label, GtkRequisition *req, ProcData *procdata)
+{
+	req->width = procdata->net_label_fixed_width = \
+		MAX(req->width, procdata->net_label_fixed_width);
+}
 
 
 
@@ -262,7 +266,7 @@ create_disk_view (ProcData *procdata)
 	GtkWidget *label, *spacer;
 	GtkWidget *scrolled;
 	GtkWidget *disk_tree;
-	GtkTreeStore *model;
+	GtkListStore *model;
 	GtkTreeViewColumn *col;
 	GtkCellRenderer *cell;
 	gint i;
@@ -280,7 +284,7 @@ create_disk_view (ProcData *procdata)
 
 	disk_box = gtk_vbox_new (FALSE, 6);
 
-	gtk_container_set_border_width (GTK_CONTAINER (disk_box), 6);
+	gtk_container_set_border_width (GTK_CONTAINER (disk_box), 12);
 
 	label = make_title_label (_("Devices"));
 	gtk_box_pack_start (GTK_BOX (disk_box), label, FALSE, FALSE, 0);
@@ -300,7 +304,7 @@ create_disk_view (ProcData *procdata)
 	gtk_box_pack_start (GTK_BOX (disk_hbox), scrolled, TRUE, TRUE, 0);
 
 
-	model = gtk_tree_store_new (10,
+	model = gtk_list_store_new (10,
 				    GDK_TYPE_PIXBUF,
 				    G_TYPE_STRING, /* device name */
 				    G_TYPE_STRING, /* directory */
@@ -396,21 +400,21 @@ static GtkWidget *
 create_sys_view (ProcData *procdata)
 {
 	GtkWidget *vbox, *hbox;
-	GtkWidget *cpu_box, *mem_box;
-	GtkWidget *cpu_hbox, *mem_hbox;
-	GtkWidget *cpu_graph_box, *mem_graph_box;
+	GtkWidget *cpu_box, *mem_box, *net_box;
+	GtkWidget *cpu_hbox, *mem_hbox, *net_hbox;
+	GtkWidget *cpu_graph_box, *mem_graph_box, *net_graph_box;
 	GtkWidget *label,*cpu_label, *spacer;
 	GtkWidget *table;
 	GtkWidget *color_picker;
 	GtkSizeGroup *sizegroup;
 	GdkColor color;
-	LoadGraph *cpu_graph, *mem_graph;
+	LoadGraph *cpu_graph, *mem_graph, *net_graph;
 	gint i;
 
 
 	vbox = gtk_vbox_new (FALSE, 18);
 
-	gtk_container_set_border_width (GTK_CONTAINER (vbox), 6);
+	gtk_container_set_border_width (GTK_CONTAINER (vbox), 12);
 
 	/* The CPU BOX */
 
@@ -457,9 +461,14 @@ create_sys_view (ProcData *procdata)
 			    G_CALLBACK (cb_cpu_color_changed), GINT_TO_POINTER (i));
 		gtk_box_pack_start (GTK_BOX (temp_hbox), color_picker, FALSE, FALSE, 0);
 		
-		text = g_strdup_printf (_("CPU%d:"), i+1);
+		if(procdata->config.num_cpus == 1) {
+			text = g_strdup (_("CPU:"));
+		}
+		else {
+			text = g_strdup_printf (_("CPU%d:"), i+1);
+		}
 		label = gtk_label_new (text);
-		gtk_box_pack_start (GTK_BOX (temp_hbox), label, FALSE, FALSE, 0);
+		gtk_box_pack_start (GTK_BOX (temp_hbox), label, FALSE, FALSE, 6);
 		g_free (text);
 		
 		cpu_label = gtk_label_new (NULL);
@@ -564,6 +573,99 @@ create_sys_view (ProcData *procdata)
 			  GTK_FILL, 0, 0, 0);
 			  
 	procdata->mem_graph = mem_graph;
+
+	/* The net box */
+	net_box = gtk_vbox_new (FALSE, 6);
+	gtk_box_pack_start (GTK_BOX (vbox), net_box, TRUE, TRUE, 0);
+
+	label = make_title_label (_("Network History"));
+	gtk_widget_show (label);
+	gtk_box_pack_start (GTK_BOX (net_box), label, FALSE, FALSE, 0);
+
+	net_hbox = gtk_hbox_new (FALSE, 0);
+	gtk_box_pack_start (GTK_BOX (net_box), net_hbox, TRUE, TRUE, 0);
+
+	spacer = gtk_label_new ("    ");
+	gtk_box_pack_start (GTK_BOX (net_hbox), spacer, FALSE, FALSE, 0);
+
+	net_graph_box = gtk_vbox_new (FALSE, 6);
+	gtk_box_pack_start (GTK_BOX (net_hbox), net_graph_box, TRUE, TRUE, 0);
+
+	net_graph = load_graph_new (LOAD_GRAPH_NET, procdata);
+	gtk_box_pack_start (GTK_BOX (net_graph_box), net_graph->main_widget,
+			    TRUE, TRUE, 0);
+
+	table = gtk_table_new (2, 5, FALSE);
+	gtk_table_set_row_spacings (GTK_TABLE (table), 6);
+	gtk_table_set_col_spacings (GTK_TABLE (table), 12);
+	gtk_box_pack_start (GTK_BOX (net_graph_box), table,
+			    FALSE, FALSE, 0);
+
+	color.red   = net_graph->colors[2].red;
+	color.green = net_graph->colors[2].green;
+	color.blue  = net_graph->colors[2].blue;
+	color_picker = gtk_color_button_new_with_color (&color);
+	g_signal_connect (G_OBJECT (color_picker), "color_set",
+			    G_CALLBACK (cb_net_in_color_changed), procdata);
+	gtk_table_attach (GTK_TABLE (table), color_picker, 0, 1, 0, 1, 0, 0, 0, 0);
+
+	label = gtk_label_new (_("Receive:"));
+	gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
+	gtk_table_attach (GTK_TABLE (table), label, 1, 2, 0, 1, GTK_FILL, 0, 0, 0);
+
+	hbox = gtk_hbox_new (FALSE, 0);
+	g_signal_connect (G_OBJECT (hbox), "size_request",
+			  G_CALLBACK (net_size_request), procdata);
+
+	net_graph->net_in_label = gtk_label_new ("");
+	gtk_misc_set_alignment (GTK_MISC (net_graph->net_in_label), 0.0, 0.5);
+	gtk_box_pack_start (GTK_BOX (hbox), net_graph->net_in_label, FALSE, FALSE, 0);
+
+	gtk_table_attach (GTK_TABLE (table), hbox, 2, 3, 0, 1, GTK_FILL, 0, 0, 0);
+
+	label = gtk_label_new (_("Total:"));
+	gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
+	gtk_table_attach (GTK_TABLE (table), label, 3, 4, 0, 1, GTK_FILL, 0, 0, 0);
+
+	net_graph->net_in_total_label = gtk_label_new ("");
+	gtk_misc_set_alignment (GTK_MISC (net_graph->net_in_total_label), 0.0, 0.5);
+	gtk_table_attach (GTK_TABLE (table), net_graph->net_in_total_label, 4, 5, 0, 1,
+			  GTK_FILL, 0, 0, 0);
+
+	color.red   = net_graph->colors[3].red;
+	color.green = net_graph->colors[3].green;
+	color.blue  = net_graph->colors[3].blue;
+	color_picker = gtk_color_button_new_with_color (&color);
+	g_signal_connect (G_OBJECT (color_picker), "color_set",
+			    G_CALLBACK (cb_net_out_color_changed), procdata);
+	gtk_table_attach (GTK_TABLE (table), color_picker, 0, 1, 1, 2, 0, 0, 0, 0);
+
+	label = gtk_label_new (_("Send:"));
+	gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
+	gtk_table_attach (GTK_TABLE (table), label, 1, 2, 1, 2, GTK_FILL, 0, 0, 0);
+
+	hbox = gtk_hbox_new (FALSE, 0);
+	g_signal_connect (G_OBJECT (hbox), "size_request",
+			  G_CALLBACK (net_size_request), procdata);
+
+	net_graph->net_out_label = gtk_label_new ("");
+	gtk_misc_set_alignment (GTK_MISC (net_graph->net_out_label), 0.0, 0.5);
+	gtk_box_pack_start (GTK_BOX (hbox), net_graph->net_out_label, FALSE, FALSE, 0);
+
+	gtk_table_attach (GTK_TABLE (table), hbox, 2, 3, 1, 2, GTK_FILL, 0, 0, 0);
+
+	label = gtk_label_new (_("Total:"));
+	gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
+	gtk_table_attach (GTK_TABLE (table), label, 3, 4, 1, 2, GTK_FILL, 0, 0, 0);
+
+	net_graph->net_out_total_label = gtk_label_new ("");
+	gtk_misc_set_alignment (GTK_MISC (net_graph->net_out_total_label), 0.0, 0.5);
+	gtk_table_attach (GTK_TABLE (table), net_graph->net_out_total_label, 4, 5, 1, 2,
+			  GTK_FILL, 0, 0, 0);
+
+	procdata->net_graph = net_graph;
+
+
 	gtk_widget_show_all (vbox);
 
 	return vbox;
@@ -678,6 +780,13 @@ create_main_window (ProcData *procdata)
 	                                     G_N_ELEMENTS (toggle_menu_entries),
 	                                     procdata);
 
+	gtk_action_group_add_radio_actions (procdata->action_group,
+					    radio_menu_entries,
+					    G_N_ELEMENTS (radio_menu_entries),
+					    procdata->config.whose_process,
+					    G_CALLBACK(cb_radio_processes),
+					    procdata);
+
 	gtk_ui_manager_insert_action_group (procdata->uimanager,
 	                                    procdata->action_group,
 	                                    0);
