@@ -263,7 +263,7 @@ procdialog_create_renice_dialog (ProcData *data)
 	gtk_table_attach (GTK_TABLE (table), label, 0, 1, 0, 2,
 			  0, 0, 0, 0);
 	
-	renice_adj = gtk_adjustment_new (info->nice, -20, 20, 1, 1, 0);
+	renice_adj = gtk_adjustment_new (info->nice, RENICE_VAL_MIN, RENICE_VAL_MAX, 1, 1, 0);
 	new_nice_value = 0;
 	hscale = gtk_hscale_new (GTK_ADJUSTMENT (renice_adj));
 	gtk_label_set_mnemonic_widget (GTK_LABEL (label), hscale);
@@ -432,7 +432,7 @@ create_proc_field_page (ProcData *procdata)
 	GtkWidget *scrolled;
 	GtkWidget *label;
 	GtkWidget *tree = procdata->tree, *treeview;
-	GList *columns = NULL;
+	GList *it, *columns;
 	GtkListStore *model;
 	GtkTreeViewColumn *column;
 	GtkCellRenderer *cell;
@@ -482,8 +482,9 @@ create_proc_field_page (ProcData *procdata)
 	
 	columns = gtk_tree_view_get_columns (GTK_TREE_VIEW (tree));
 	
-	while (columns) {
-		GtkTreeViewColumn *column = columns->data;
+	for(it = columns; it; it = it->next)
+	{
+		GtkTreeViewColumn *column = it->data;
 		GtkTreeIter iter;
 		const gchar *title;
 		gboolean visible;
@@ -496,11 +497,9 @@ create_proc_field_page (ProcData *procdata)
 		
 		gtk_list_store_append (model, &iter);
 		gtk_list_store_set (model, &iter, 0, visible, 1, title, 2, column,-1);
-			    
-		
-		columns = g_list_next (columns);
 	}
-		
+
+	g_list_free(columns);
 
 	return vbox;
 }
@@ -541,15 +540,15 @@ procdialog_create_preferences_dialog (ProcData *procdata)
 	/* have to show at least 4 items to respect HIG. I don't know   */
 	/* any function to set list height by contents/items inside it. */
 	gtk_window_set_default_size (GTK_WINDOW (dialog), 400, 420);
-	gtk_container_set_border_width (GTK_CONTAINER (dialog), 6);
+	gtk_container_set_border_width (GTK_CONTAINER (dialog), 5);
 	gtk_dialog_set_has_separator (GTK_DIALOG (dialog), FALSE);
 	prefs_dialog = dialog;
 	
 	main_vbox = GTK_DIALOG (dialog)->vbox;
-	gtk_box_set_spacing (GTK_BOX (main_vbox), 12);
+	gtk_box_set_spacing (GTK_BOX (main_vbox), 2);
 	
 	notebook = gtk_notebook_new ();
-	gtk_container_set_border_width (GTK_CONTAINER (notebook), 6);
+	gtk_container_set_border_width (GTK_CONTAINER (notebook), 5);
 	gtk_box_pack_start (GTK_BOX (main_vbox), notebook, TRUE, TRUE, 0);
 	
 	proc_box = gtk_vbox_new (FALSE, 18);
@@ -589,8 +588,8 @@ procdialog_create_preferences_dialog (ProcData *procdata)
 	
 	update = (gfloat) procdata->config.update_interval;
 	adjustment = (GtkAdjustment *) gtk_adjustment_new(update / 1000.0,
-							  MIN_UPDATE_INTERVAL,
-							  MAX_UPDATE_INTERVAL,
+							  MIN_UPDATE_INTERVAL / 1000,
+							  MAX_UPDATE_INTERVAL / 1000,
 							  0.25,
 							  1.0,
 							  1.0);
@@ -763,7 +762,6 @@ procdialog_create_preferences_dialog (ProcData *procdata)
 	label = gtk_label_new_with_mnemonic (_("Update _interval:"));
 	gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
 	gtk_box_pack_start (GTK_BOX (hbox2), label, FALSE, FALSE, 0);
-	gtk_size_group_add_widget (size, label);
 	
 	hbox3 = gtk_hbox_new (FALSE, 6);
 	gtk_box_pack_start (GTK_BOX (hbox2), hbox3, TRUE, TRUE, 0);
