@@ -126,8 +126,13 @@ timeouts_changed_cb (GConfClient *client, guint id, GConfEntry *entry, gpointer
 		procdata->mem_graph->timer_index = -1;
 		procdata->mem_graph->speed = procdata->config.graph_update_interval;
 	
+		gtk_timeout_remove (procdata->net_graph->timer_index);
+		procdata->net_graph->timer_index = -1;
+		procdata->net_graph->speed = procdata->config.graph_update_interval;
+
 		load_graph_start (procdata->cpu_graph);
 		load_graph_start (procdata->mem_graph);	
+		load_graph_start (procdata->net_graph);
 	}
 	else {
 		
@@ -154,11 +159,13 @@ color_changed_cb (GConfClient *client, guint id, GConfEntry *entry, gpointer dat
 		gdk_color_parse (color, &procdata->config.bg_color);
 		procdata->cpu_graph->colors[0] = procdata->config.bg_color;
 		procdata->mem_graph->colors[0] = procdata->config.bg_color;
+		procdata->net_graph->colors[0] = procdata->config.bg_color;
 	}
 	else if (g_str_equal (key, "/apps/procman/frame_color")) {
 		gdk_color_parse (color, &procdata->config.frame_color);
 		procdata->cpu_graph->colors[1] = procdata->config.frame_color;
 		procdata->mem_graph->colors[1] = procdata->config.frame_color;
+		procdata->net_graph->colors[1] = procdata->config.frame_color;
 	}
 	else if (g_str_equal (key, "/apps/procman/cpu_color")) {
 		gdk_color_parse (color, &procdata->config.cpu_color[0]);
@@ -185,9 +192,18 @@ color_changed_cb (GConfClient *client, guint id, GConfEntry *entry, gpointer dat
 		gdk_color_parse (color, &procdata->config.swap_color);
 		procdata->mem_graph->colors[3] = procdata->config.swap_color;
 	}
+	else if (g_str_equal (key, "/apps/procman/net_in_color")) {
+		gdk_color_parse (color, &procdata->config.net_in_color);
+		procdata->net_graph->colors[2] = procdata->config.net_in_color;
+	}
+	else if (g_str_equal (key, "/apps/procman/net_out_color")) {
+		gdk_color_parse (color, &procdata->config.net_out_color);
+		procdata->net_graph->colors[3] = procdata->config.net_out_color;
+	}
 		
 	procdata->cpu_graph->colors_allocated = FALSE;
 	procdata->mem_graph->colors_allocated = FALSE;
+	procdata->net_graph->colors_allocated = FALSE;
 		
 }
 
@@ -227,6 +243,7 @@ procman_data_new (GConfClient *client)
 	pd->blacklist = NULL;
 	pd->cpu_graph = NULL;
 	pd->mem_graph = NULL;
+	pd->net_graph = NULL;
 	pd->disk_timeout = -1;
 
 	glibtop_get_loadavg(&loadavg);
@@ -304,7 +321,7 @@ procman_data_new (GConfClient *client)
 	
 	color = gconf_client_get_string (client, "/apps/procman/cpu_color", NULL);
 	if (!color)
-		color = g_strdup ("#0000007200b3");
+		color = g_strdup ("#000000a200ff");
 	gconf_client_notify_add (client, "/apps/procman/cpu_color", 
 			  	 color_changed_cb, pd, NULL, NULL);
 	gdk_color_parse(color, &pd->config.cpu_color[0]);
@@ -325,7 +342,7 @@ procman_data_new (GConfClient *client)
 	}
 	color = gconf_client_get_string (client, "/apps/procman/mem_color", NULL);
 	if (!color)
-		color = g_strdup ("#000000b3005b");
+		color = g_strdup ("#000000ff0082");
 	gconf_client_notify_add (client, "/apps/procman/mem_color", 
 			  	 color_changed_cb, pd, NULL, NULL);
 	gdk_color_parse(color, &pd->config.mem_color);
@@ -334,11 +351,27 @@ procman_data_new (GConfClient *client)
 	
 	color = gconf_client_get_string (client, "/apps/procman/swap_color", NULL);
 	if (!color)
-		color = g_strdup ("#008b000000c3");
+		color = g_strdup ("#00b6000000ff");
 	gconf_client_notify_add (client, "/apps/procman/swap_color", 
 			  	 color_changed_cb, pd, NULL, NULL);
 	gdk_color_parse(color, &pd->config.swap_color);
 	g_free (color);
+
+	color = gconf_client_get_string (client, "/apps/procman/net_in_color", NULL);
+	if (!color)
+		color = g_strdup ("#000000f200f2");
+	gconf_client_notify_add (client, "/apps/procman/net_in_color",
+			  	 color_changed_cb, pd, NULL, NULL);
+	gdk_color_parse(color, &pd->config.net_in_color);
+	g_free (color);
+
+	color = gconf_client_get_string (client, "/apps/procman/net_out_color", NULL);
+	if (!color)
+		color = g_strdup ("#00f2000000c1");
+	gconf_client_notify_add (client, "/apps/procman/net_out_color",
+			  	 color_changed_cb, pd, NULL, NULL);
+	gdk_color_parse(color, &pd->config.net_out_color);
+	g_free (color);
 	
 	get_blacklist (pd, client);
 	
@@ -388,10 +421,10 @@ gboolean
 procman_get_tree_state (GConfClient *client, GtkWidget *tree, const gchar *prefix)
 {
 	GtkTreeModel *model;
+	GList *columns, *it;
 	gint sort_col;
 	GtkSortType order;
 	gchar *key;
-	gint i;
 	
 	g_return_val_if_fail (tree, FALSE);
 	g_return_val_if_fail (prefix, FALSE);
@@ -413,33 +446,54 @@ procman_get_tree_state (GConfClient *client, GtkWidget *tree, const gchar *prefi
 		gtk_tree_sortable_set_sort_column_id (GTK_TREE_SORTABLE (model),
 					      	      sort_col,
 					              order);
-	
-	for(i = 0; i < NUM_COLUMNS; ++i) {
+
+	columns = gtk_tree_view_get_columns (GTK_TREE_VIEW (tree));
+
+	for(it = columns; it; it = it->next)
+	{
 		GtkTreeViewColumn *column;
 		GConfValue *value = NULL;
 		gint width;
 		gboolean visible;
-		
-		
-		key = g_strdup_printf ("%s/col_%d_width", prefix, i);
+		int id;
+
+		column = it->data;
+		id = gtk_tree_view_column_get_sort_column_id (column);
+
+		key = g_strdup_printf ("%s/col_%d_width", prefix, id);
 		value = gconf_client_get (client, key, NULL);
 		g_free (key);
-		
+
 		if (value != NULL) {
 			width = gconf_value_get_int(value);
 			gconf_value_free (value);
-		
-			key = g_strdup_printf ("%s/col_%d_visible", prefix, i);
+
+			key = g_strdup_printf ("%s/col_%d_visible", prefix, id);
 			visible = gconf_client_get_bool (client, key, NULL);
 			g_free (key);
-		
-			column = gtk_tree_view_get_column (GTK_TREE_VIEW (tree), i);
+
+			column = gtk_tree_view_get_column (GTK_TREE_VIEW (tree), id);
 			if(!column) continue;
 			gtk_tree_view_column_set_visible (column, visible);
 			if (width > 0)
 				gtk_tree_view_column_set_fixed_width (column, width);
 		}
 	}
+
+	if(g_str_has_suffix(prefix, "proctree"))
+	{
+		GSList *order;
+		char *key;
+
+		key = g_strdup_printf("%s/columns_order", prefix);
+		order = gconf_client_get_list(client, key, GCONF_VALUE_INT, NULL);
+		proctable_set_columns_order(GTK_TREE_VIEW(tree), order);
+
+		g_slist_free(order);
+		g_free(key);
+	}
+
+	g_list_free(columns);
 	
 	return TRUE;
 }
@@ -448,10 +502,9 @@ void
 procman_save_tree_state (GConfClient *client, GtkWidget *tree, const gchar *prefix)
 {
 	GtkTreeModel *model;
-	GList *columns;
+	GList *it, *columns;
 	gint sort_col;
 	GtkSortType order;
-	gint i = 0;
 	
 	g_return_if_fail (tree);
 	g_return_if_fail (prefix);
@@ -471,28 +524,51 @@ procman_save_tree_state (GConfClient *client, GtkWidget *tree, const gchar *pref
 	}			       
 	
 	columns = gtk_tree_view_get_columns (GTK_TREE_VIEW (tree));
-	
-	while (columns) {
-		GtkTreeViewColumn *column = columns->data;
+
+	for(it = columns; it; it = it->next)
+	{
+		GtkTreeViewColumn *column;
 		gboolean visible;
 		gint width;
 		gchar *key;
-		
+		int id;
+
+		column = it->data;
+		id = gtk_tree_view_column_get_sort_column_id (column);
 		visible = gtk_tree_view_column_get_visible (column);
 		width = gtk_tree_view_column_get_width (column);
-		
-		key = g_strdup_printf ("%s/col_%d_width", prefix, i);
+
+		key = g_strdup_printf ("%s/col_%d_width", prefix, id);
 		gconf_client_set_int (client, key, width, NULL);
 		g_free (key);
-		
-		key = g_strdup_printf ("%s/col_%d_visible", prefix, i);
+
+		key = g_strdup_printf ("%s/col_%d_visible", prefix, id);
 		gconf_client_set_bool (client, key, visible, NULL);
 		g_free (key);
-		
-		columns = g_list_next (columns);
-		i++;
 	}
-	
+
+	if(g_str_has_suffix(prefix, "proctree"))
+	{
+		GSList *order;
+		char *key;
+		GError *error = NULL;
+
+		key = g_strdup_printf("%s/columns_order", prefix);
+		order = proctable_get_columns_order(GTK_TREE_VIEW(tree));
+
+		if(!gconf_client_set_list(client, key, GCONF_VALUE_INT, order, &error))
+		{
+			g_error("Could not save GConf key '%s' : %s",
+				key,
+				error->message);
+			g_error_free(error);
+		}
+
+		g_slist_free(order);
+		g_free(key);
+	}
+
+	g_list_free(columns);
 }
 
 void
@@ -523,6 +599,37 @@ procman_save_config (ProcData *data)
 	
 }
 
+static guint32
+get_startup_timestamp ()
+{
+	const gchar *startup_id_env;
+	gchar *startup_id = NULL;
+	gchar *time_str;
+	gulong retval = 0;
+
+	/* we don't unset the env, since startup-notification
+	 * may still need it */
+	startup_id_env = g_getenv ("DESKTOP_STARTUP_ID");
+	if (startup_id_env == NULL)
+		goto out;
+
+	startup_id = g_strdup (startup_id_env);
+
+	time_str = g_strrstr (startup_id, "_TIME");
+	if (time_str == NULL)
+		goto out;
+
+	/* Skip past the "_TIME" part */
+	time_str += 5;
+
+	retval = strtoul (time_str, NULL, 0);
+
+ out:
+	g_free (startup_id);
+
+	return retval;
+}
+
 
 static void
 cb_server (const gchar *msg, gpointer user_data)
@@ -538,15 +645,14 @@ cb_server (const gchar *msg, gpointer user_data)
 
 	timestamp = strtoul(msg, NULL, 0);
 
-	if(timestamp)
+	if (timestamp == 0)
 	{
-		gdk_x11_window_set_user_time (window, timestamp);
-	}
-	else
-	{
-		g_warning ("Couldn't get timestamp");
+		/* fall back to rountripping to X */
+		timestamp = gdk_x11_get_server_time (window);
 	}
 
+	gdk_x11_window_set_user_time (window, timestamp);
+
 	gtk_window_present (GTK_WINDOW(procdata->app));
 }
 
@@ -568,11 +674,22 @@ init_volume_monitor(ProcData *procdata)
 int
 main (int argc, char *argv[])
 {
+	guint32 startup_timestamp;
 	GnomeProgram *procman;
 	GConfClient *client;
 	ProcData *procdata;
 	BaconMessageConnection *conn;
 
+	bindtextdomain (GETTEXT_PACKAGE, PACKAGE_LOCALE_DIR);
+	bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
+	textdomain (GETTEXT_PACKAGE);
+
+	startup_timestamp = get_startup_timestamp();
+
+	procman = gnome_program_init ("gnome-system-monitor", VERSION, 
+				       LIBGNOMEUI_MODULE, argc, argv,
+				      GNOME_PARAM_APP_DATADIR,DATADIR, NULL);
+
 	conn = bacon_message_connection_new ("gnome-system-monitor");
 	if (!conn) g_error("Couldn't connect to gnome-system-monitor");
 
@@ -582,34 +699,20 @@ main (int argc, char *argv[])
 	}
 	else /* client */
 	{
-		const char *desktop_startup_id, *timestamp;
+		char *timestamp;
 
-		timestamp = NULL;
-		desktop_startup_id = g_getenv("DESKTOP_STARTUP_ID");
-
-		if(desktop_startup_id)
-		{
-			timestamp = strstr(desktop_startup_id, "_TIME");
-		}
-
-		if(!timestamp)
-		{
-			g_warning ("Couldn't get $DESKTOP_STARTUP_ID");
-			timestamp = "0";
-		}
+		timestamp = g_strdup_printf ("%" G_GUINT32_FORMAT, startup_timestamp);
 
 		bacon_message_connection_send (conn, timestamp);
+
+		gdk_notify_startup_complete ();
+
+		g_free (timestamp);
 		bacon_message_connection_free (conn);
-		return 1;
+
+		exit (0);
 	}
 
-	bindtextdomain (GETTEXT_PACKAGE, PACKAGE_LOCALE_DIR);
-	bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
-	textdomain (GETTEXT_PACKAGE);
-
-	procman = gnome_program_init ("gnome-system-monitor", VERSION, 
-				       LIBGNOMEUI_MODULE, argc, argv,
-				      GNOME_PARAM_APP_DATADIR,DATADIR, NULL);
 	gtk_window_set_default_icon_name ("gnome-monitor");
 		    
 	gconf_init (argc, argv, NULL);
